---
title: About
---

## ESMValTool

The Earth System Model Evaluation Tool, ESMValTool, is a python-based
software toolkit built to evaluate models of the Earths climate.

ESMVAlTool is made to be:

- Versatile
- Flexible
- Modular
- Standardised 
- Community driven

The toolkit is built with a sensible and modern code development process.
Where possible, we follow software development best practices,
including code review & monitoring, unit & integration testing,
and fully transparent design decisions.

ESMValTool is open source and available on github, and is written
in PEP8-compliant Python3.

For more details on ESMValTool, please go to:

- [ESMValTool home page](https://esmvaltool.org)
- [ESMValTool Documentation page](https://docs.esmvaltool.org)


## ESMValTool_Tutorial

The ESMValTool tutorial was made to help people learn how to install, use,
and develop ESMValTool.

The tutorial uses the software carpentry format and tools, and can be
followed both independently and in a taught tutorial environment.

The tutorial has been produced by the ESMValTool User Engagement team,
and may be forked, developped and rehosted by other groups.

## License

Please see
[license information](https://github.com/ESMValGroup/ESMValTool_Tutorial/blob/master/LICENSE.md).

## Citation

Please see
[citation information](https://github.com/ESMValGroup/ESMValTool_Tutorial/blob/master/CITATION.cff).

## Acknowledgements

Citing the ESMValTool paper and registering your papers
will serve to document the scientific impact of the Software,
which is of vital importance for securing future funding.
You should consider this an obligation if you have taken advantage of the
ESMValTool, which represents the end product of considerable effort by the
development teams.

Please cite ESMValTool paper as:

@article{Righi2020,
  doi = {10.5194/gmd-13-1179-2020},
  url = {https://doi.org/10.5194/gmd-13-1179-2020},
  year = {2020},
  month = mar,
  publisher = {Copernicus {GmbH}},
  volume = {13},
  number = {3},
  pages = {1179--1199},
  author = {Mattia Righi and Bouwe Andela and Veronika Eyring and Axel Lauer and Valeriu Predoi
  and Manuel Schlund and Javier Vegas-Regidor and Lisa Bock and Bj\"{o}rn Br\"{o}tz and
  Lee de Mora and Faruk Diblen and Laura Dreyer and Niels Drost and Paul Earnshaw and
  Birgit Hassler and Nikolay Koldunov and Bill Little and Saskia Loosveldt Tomas and Klaus Zimmermann},
  title = {Earth System Model Evaluation Tool ({ESMValTool}) v2.0 {\textendash} technical overview},
  journal = {Geoscientific Model Development}
}

and cite ESMValTool and ESMValCore software as:

@misc{https://doi.org/10.5281/zenodo.3401363,
  doi = {10.5281/ZENODO.3401363},
  url = {https://zenodo.org/record/3401363},
  author = {Andela,  Bouwe and Broetz,  Bjoern and de Mora,  Lee and Drost,  Niels and
  Eyring, Veronika and Koldunov,  Nikolay and Lauer,  Axel and Mueller,  Benjamin and
  Predoi,  Valeriu and Righi,  Mattia and Schlund,  Manuel and Vegas-Regidor,  Javier and
  Zimmermann,  Klaus and Adeniyi,  Kemisola and Arnone,  Enrico and Bellprat,  Omar and
  Berg,  Peter and Bock,  Lisa and Caron,  Louis-Philippe and Carvalhais,  Nuno and
  Cionni,  Irene and Cortesi,  Nicola and Corti,  Susanna and Crezee,  Bas and
  Davin,  Edouard Leopold and Davini,  Paolo and Deser,  Clara and Diblen,  Faruk and
  Docquier,  David and Dreyer,  Laura and Ehbrecht,  Carsten and Earnshaw,  Paul and
  Gier,  Bettina and Gonzalez-Reviriego,  Nube and Goodman,  Paul and Hagemann,  Stefan and
  von Hardenberg,  Jost and Hassler,  Birgit and Hunter,  Alasdair and Kadow,  Christopher and
  Kindermann,  Stephan and Koirala,  Sujan and Lledó,  Lloren\c{c} and Lejeune,  Quentin and
  Lembo,  Valerio and Little,  Bill and Loosveldt-Tomas,  Saskia and Lorenz,  Ruth
  and Lovato,  Tomas and Lucarini,  Valerio and Massonnet,  Fran\c{c}ois
  and Mohr,  Christian Wilhelm and Amarjiit,  Pandde and Pérez-Zanón,  Núria
  and Phillips,  Adam and Russell,  Joellen and Sandstad,  Marit and Sellar,  Alistair
  and Senftleben,  Daniel and Serva,  Federico and Sillmann,  Jana and Stacke,  Tobias
  and Swaminathan,  Ranjini and Torralba,  Verónica and Weigel,  Katja},
  title = {ESMValTool},
  publisher = {Zenodo},
  year = {2020},
  copyright = {Apache License 2.0}
}

@misc{https://doi.org/10.5281/zenodo.3387139,
  doi = {10.5281/ZENODO.3387139},
  url = {https://zenodo.org/record/3387139},
  author = {Andela,  Bouwe and Broetz,  Bjoern and de Mora,  Lee and Drost,  Niels and
  Eyring,  Veronika and Koldunov,  Nikolay and Lauer,  Axel and Predoi,  Valeriu and
  Righi,  Mattia and Schlund,  Manuel and Vegas-Regidor,  Javier and Zimmermann,  Klaus and
  Bock,  Lisa and Diblen,  Faruk and Dreyer,  Laura and Earnshaw,  Paul and
  Hassler,  Birgit and Little,  Bill and Loosveldt-Tomas,  Saskia},
  title = {ESMValCore},
  publisher = {Zenodo},
  year = {2020},
  copyright = {Apache License 2.0}
}

See additional resources at https://www.esmvaltool.org/references.html.

The technical development work for ESMValTool v2.0 was funded by
[various projects](https://www.esmvaltool.org/acknowledgements.html).


{% include escience_academy.html %}
{% include links.md %}
